@@ -1,7 +1,7 @@
 /*
  * This file is part of the  X2Go Project - http://www.x2go.org
- * Copyright (C) 2011-2014 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- * Copyright (C) 2011-2014 Moritz 'Morty' Strübe <morty@gmx.net>
+ * Copyright (C) 2011-2015 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+ * Copyright (C) 2011-2015 Moritz 'Morty' Strübe <morty@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,6 @@ int main( int argc, char *argv[] ) {
 
 	argv[0] = "x2gosqlitewrapper.pl";
 	// execute the script, running with user-rights of this binary
-	execv(x2gosqlitewrapper, argv);
+	return execv(x2gosqlitewrapper, argv);
 
 }
